@@ -1,6 +1,7 @@
 import re
 from typing import Union
 
+
 ENOTATION_REGEXP = re.compile(r"\d+(\.\d*)?e[+-]?\d+?")
 
 
@@ -49,8 +50,8 @@ class ENotationIO:
         if not re.match(ENOTATION_REGEXP, s):
             raise ValueError
 
-        digits, _, exponent = s.partition("e")
-        exponent = int(exponent)
+        digits, _, sexponent = s.partition("e")
+        exponent = int(sexponent)
         if "." in digits:
             digits, decimals = digits.split(".")
             decimals = decimals.rstrip("0")
